@@ -380,8 +380,14 @@ class GSPeerConnectionBroadcasterPiSocketv2:
 
             # loop.run_until_complete( pc.setLocalDescription(awaitpc.createOffer()))
             # asyncio.run(create_and_set_local_description(pc))
-            async with pc:
-                await create_and_set_local_description(pc)
+            loop = asyncio.new_event_loop()
+            asyncio.set_event_loop(loop)
+
+            # Call the function synchronously using the event loop
+            loop.run_until_complete(create_and_set_local_description(pc))
+
+            # Close the event loop
+            loop.close()
 
 
 
@@ -400,14 +406,29 @@ class GSPeerConnectionBroadcasterPiSocketv2:
                         description = ast.literal_eval(description)
                     desc = type('new_dict', (object,), description)
                     answer = RTCSessionDescription(sdp=description["sdp"], type=description["type"])
+                    loop = asyncio.new_event_loop()
+                    asyncio.set_event_loop(loop)
+
+                    # Call the function synchronously using the event loop
+                    loop.run_until_complete(self.peerConnections[id].setRemoteDescription(answer))
+
+                    # Close the event loop
+                    loop.close()
 
-                    asyncio.run(self.peerConnections[id].setRemoteDescription(answer))
 
         @self.sio.event
         def disconnectBroadcaster(id, desc):
             if id in self.peerConnections:
                 self._logger.info("Disconnected Peer")
-                asyncio.run(self.peerConnections[id].close())
+
+                loop = asyncio.new_event_loop()
+                asyncio.set_event_loop(loop)
+
+                loop.run_until_complete(asyncio.run(self.peerConnections[id].close()))
+
+                loop.close()
+
+
                 self.peerConnections.pop(id, None)
 
         @self.sio.event
